@@ -5,9 +5,9 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="381"/>
+        <location filename="../mainwindow.cpp" line="402"/>
         <source>MX Tools</source>
-        <translation type="unfinished">MX Araçlar</translation>
+        <translation type="unfinished">MX Araçları</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="53"/>
@@ -47,7 +47,7 @@
     <message>
         <location filename="../mainwindow.ui" line="263"/>
         <source>These MX applications save time and effort with important tasks.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bu MX uygulamaları önemli görevlerde zamandan ve emekten tasarruf sağlar.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="279"/>
@@ -60,42 +60,42 @@
         <translation type="unfinished">Ara</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../mainwindow.cpp" line="401"/>
         <source>About MX Tools</source>
         <translation type="unfinished">MX Araçları Hakkında</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="381"/>
+        <location filename="../mainwindow.cpp" line="402"/>
         <source>Version: </source>
         <translation type="unfinished">Sürüm</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="383"/>
+        <location filename="../mainwindow.cpp" line="404"/>
         <source>Configuration Tools for MX Linux</source>
         <translation type="unfinished">MX Linux için Yapılandırma Araçları</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="384"/>
+        <location filename="../mainwindow.cpp" line="405"/>
         <source>Copyright (c) MX Linux</source>
         <translation type="unfinished">Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="385"/>
+        <location filename="../mainwindow.cpp" line="406"/>
         <source>License</source>
         <translation type="unfinished">Ruhsat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="386"/>
+        <location filename="../mainwindow.cpp" line="407"/>
         <source>Changelog</source>
         <translation type="unfinished">Değişim günlüğü</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="387"/>
+        <location filename="../mainwindow.cpp" line="408"/>
         <source>Cancel</source>
         <translation type="unfinished">İptal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="402"/>
+        <location filename="../mainwindow.cpp" line="423"/>
         <source>&amp;Close</source>
         <translation type="unfinished">&amp;Kapat</translation>
     </message>
@@ -104,7 +104,7 @@
     <name>mxtools</name>
     <message>
         <source>MX Tools</source>
-        <translation type="vanished">MX Araçlar</translation>
+        <translation type="vanished">MX Araçları</translation>
     </message>
     <message>
         <source>About this application</source>
@@ -134,6 +134,10 @@
         <source>Manual</source>
         <translation type="vanished">El ile</translation>
     </message>
+    <message>
+        <source>These MX applications save time and effort with important tasks.</source>
+        <translation type="vanished">Bu MX uygulamaları önemli görevlerde zamandan ve emekten tasarruf sağlar.</translation>
+    </message>
     <message>
         <source>Hide individual tools from the menu</source>
         <translation type="vanished">Bireysel araçları menüde gösterme</translation>
